oc\_ocdm.graph.entities.bibliographic.agent\_role module
--------------------------------------------------------

.. automodule:: oc_ocdm.graph.entities.bibliographic.agent_role
   :members:
   :undoc-members:
   :show-inheritance:
